package com.xkrs.websocket.service;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.websocket.*;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArraySet;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * @author xkrs
 */
@Component
@ServerEndpoint(value = "/ws/asset")
public class WebSocketServer {

    @PostConstruct
    public void init() {
        System.out.println("websocketBroker loading......");
    }

    private static Logger log = LoggerFactory.getLogger(WebSocketServer.class);
    private static final AtomicInteger ONLINE_COUNT = new AtomicInteger(0);
    private static CopyOnWriteArraySet<Session> sessionSet = new CopyOnWriteArraySet<>();

    /**
     * 连接建立
     */
    @OnOpen
    public void onOpen(Session session) {
        sessionSet.add(session);
        //在线加1
        int cnt = ONLINE_COUNT.incrementAndGet();
        //log.info("have a new connect:{}", cnt);
        //sendMsg(session, "connect success");
    }

    /**
     * 连接关闭
     *
     * @param session
     */
    @OnClose
    public void onClose(Session session) {
        sessionSet.remove(session);
        //在线减1
        int cnt = ONLINE_COUNT.decrementAndGet();
        log.info("have a connect close:{}", cnt);
    }

    /**
     * 收到客户端消息后调用的方法
     *
     * @param session
     * @param msg
     */
    @OnMessage
    public void onMessage(String msg, Session session) {
        log.info("receive the msg:{}", msg);
    }

    private static void sendMsg(Session session, String msg) {
        try {
            session.getBasicRemote().sendText(String.format(msg));
        } catch (IOException e) {
            log.error("发送信息出错：{}", e.getMessage());
            e.printStackTrace();
        }
    }

    private static void sendDate(Session session, Map map) {
        try {
            session.getBasicRemote().sendObject(map);
        } catch (IOException | EncodeException e) {
            log.error("发送信息出错：{}", e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * 指定session发送
     */
    public static void sendMsg(String msg, String sessionId) {
        Session session = null;
        for (Session s : sessionSet) {
            if (s.getId().equals(sessionId)) {
                session = s;
                break;
            }
        }
        if (session != null) {
            sendMsg(session, msg);
        } else {
            log.warn("not find your session");
        }
    }

    /**
     * 群发消息
     */
    public static void broadInfo(String msg) {
        for (Session s : sessionSet) {
            synchronized (sessionSet){
                if (s.isOpen()) {
                    sendMsg(s, msg);
                }
            }
        }
    }

    /**
     * 群发map消息
     * @param map
     */
    public static void broadInfoMap(Map map) {
        for (Session s : sessionSet) {
            if (s.isOpen()) {
                sendDate(s, map);
            }
        }
    }

}
